@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
 import json
 import os.path
 from tempfile import NamedTemporaryFile
 from typing import Generator
 
 import pytest
+from fixtures import experiments
 
 from chaoslib.settings import load_settings
-from chaoslib.types import Experiment, Settings
-
-from fixtures import experiments
+from chaoslib.types import Settings
 
 
 @pytest.fixture
 def settings_file() -> str:
-    return os.path.join(
-        os.path.dirname(__file__), "fixtures", "settings.yaml")
+    return os.path.join(os.path.dirname(__file__), "fixtures", "settings.yaml")
 
 
 @pytest.fixture
@@ -25,7 +22,7 @@ def settings(settings_file: str) -> Settings:
 
 @pytest.fixture
 def generic_experiment() -> Generator[str, None, None]:
-    with NamedTemporaryFile(mode='w', suffix=".json", encoding='utf-8') as f:
+    with NamedTemporaryFile(mode="w", suffix=".json", encoding="utf-8") as f:
         json.dump(experiments.Experiment, f)
         f.seek(0)
         yield f.name
