@@ -1,8 +1,12 @@
 from chaoslib.types import Configuration, Experiment, Secrets, Settings
 
 
-def configure_control(experiment: Experiment, configuration: Configuration,
-                      secrets: Secrets, settings: Settings):
+def configure_control(
+    experiment: Experiment,
+    configuration: Configuration,
+    secrets: Secrets,
+    settings: Settings,
+):
     raise RuntimeError("init control")
 
 
